netapp_ontap.models.ekmip_server_connectivity API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.ekmip_server_connectivity`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class EkmipServerConnectivitySchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the EkmipServerConnectivity object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `code GET`

    Code corresponding to the status message. Returns a 0 if a given SVM is able to communicate to the EKMIP servers of all the nodes in the cluster.

    Example: 346758

  `message GET`

    Error message set when cluster-wide EKMIP server availability from the given node is false.

    Example: embedded KMIP server status unavailable on node.

  `node GET`

    The node field of the ekmip_server_connectivity.

  `reachable GET`

    Set to true when the given node for a given SVM is able to communicate to the EKMIP servers of all the nodes in the cluster.